@@ -25,15 +25,20 @@ def scanConfigFileForErrors():
 	
 	assert type(cfg.LOWER_DOT_THRESH_SCALE) in [int, float]
 	assert type(cfg.UPPER_DOT_THRESH_SCALE) in [int, float]
+	assert cfg.LOWER_DOT_THRESH_SCALE <= cfg.UPPER_DOT_THRESH_SCALE
 	assert type(cfg.LOWER_BLOB_THRESH_SCALE) in [int, float]
+	assert cfg.LOWER_BLOB_THRESH_SCALE >= 1
 	assert type(cfg.THRESHOLD_DELTA) in [int, float]
 	
 	assert type(cfg.LOWER_CONTRAST) in [int, float]
 	assert type(cfg.UPPER_CONTRAST) in [int, float]
+	assert cfg.LOWER_CONTRAST < cfg.UPPER_CONTRAST
 	assert type(cfg.CONTRAST_DELTA) in [int, float]
 	
 	assert type(cfg.SKIPS_ALLOWED) == int
+	assert cfg.SKIPS_ALLOWED >= 0
 	assert type(cfg.REMOVE_EDGE_FRAMES) == bool
+	assert type(cfg.LIFETIME_MIN_FOR_PLOT) == int
 	
 	assert type(cfg.DOT_SIZE) == int
 	assert cfg.DOT_COLOR in matplotlibColors
@@ -148,39 +153,29 @@ SCALE = None\n\
 ############################################\n\
 \n\
 LOWER_DOT_THRESH_SCALE = 1.5\n\
-# Scaling for the lower threshold defining the brightness of the dots. The default is 1.5,\n\
-# which corresponds to 1.5 standard deviations above the mean.\n\
-# Lower this value to increase the number of faint dots detected, or raise it to reduce the number.\n\
+# Scaling for the lower threshold defining the brightness of the dots. The default is 1.5, which corresponds to 1.5 standard deviations above the mean. Lower this value to increase the number of faint dots detected, or raise it to reduce the number.\n\
 \n\
 UPPER_DOT_THRESH_SCALE = 5.0\n\
-# Scaling for the upper threshold defining the brightness of the dots. The default is 5,\n\
-# which corresponds to 5 standard deviations above the mean.\n\
-# Lower this value to reduce the number of bright dots detected, or raise it to increase the number.\n\
+# Scaling for the upper threshold defining the brightness of the dots. The default is 5, which corresponds to 5 standard deviations above the mean. Lower this value to reduce the number of bright dots detected, or raise it to increase the number.\n\
 \n\
 LOWER_BLOB_THRESH_SCALE = 2.0\n\
-# Scaling for the lower threshold defining the brightness of the blobs. The default is 2,\n\
-# which corresponds to 2 times the value of UPPER_DOT_THRESH_SCALE.\n\
-# Lower this value to increase the number of blobs detected, or raise it to reduce the number.\n\
+# Scaling for the lower threshold defining the brightness of the blobs. The default is 2, which corresponds to 2 times the value of UPPER_DOT_THRESH_SCALE. Lower this value to increase the number of blobs detected, or raise it to reduce the number.\n\
 \n\
 THRESHOLD_DELTA = 0.1\n\
-# Amount by which a threshold will change when clicking the up and down arrows in the plotting UI.\n\
-# The default value is 0.1, and will be rounded to the nearest 0.1.\n\
+# Amount by which a threshold will change when clicking the up and down arrows in the plotting UI. The default value is 0.1, and will be rounded to the nearest 0.1.\n\
 \n\
 #################################################\n\
 ############ IMAGE CONTRAST SETTINGS ############\n\
 #################################################\n\
 \n\
 LOWER_CONTRAST = 0.0\n\
-# The lower bound of the plotting range for the data. The default value is 0.0, or 0 standard\n\
-# deviations above the mean of the dataset. Decrease this value if the image is too dark.\n\
+# The lower bound of the plotting range for the data. The default value is 0.0, or 0 standard deviations above the mean of the dataset. Decrease this value if the image is too dark.\n\
 \n\
 UPPER_CONTRAST = 5.0\n\
-# The upper bound of the plotting range for the data. The default value is 5.0, or 5 standard\n\
-# deviations above the mean of the dataset. Increase this value if the image is too saturated.\n\
+# The upper bound of the plotting range for the data. The default value is 5.0, or 5 standard deviations above the mean of the dataset. Increase this value if the image is too saturated.\n\
 \n\
 CONTRAST_DELTA = 0.5\n\
-# Amount by which the contrast will change when clicking the up and down arrows in the plotting UI.\n\
-# The default value is 0.5, and will be rounded to the nearest 0.1.\n\
+# Amount by which the contrast will change when clicking the up and down arrows in the plotting UI. The default value is 0.5, and will be rounded to the nearest 0.1.\n\
 \n\
 ###########################################\n\
 ############ LIFETIME SETTINGS ############\n\
@@ -193,8 +188,7 @@ REMOVE_EDGE_FRAMES = True\n\
 # Whether edge frames should be removed from a lifetime calculation\n\
 \n\
 LIFETIME_MIN_FOR_PLOT = 1\n\
-# Minimum lifetime to mark a dot in the output figure. The default value is 1, so that all dots\n\
-# with a lifetime of 1 or greater are plotted.\n\
+# Minimum lifetime to mark a dot in the output figure. The default value is 1, so that all dots with a lifetime of 1 or greater are plotted.\n\
 \n\
 ######################################\n\
 ############ DOT SETTINGS ############\n\
@@ -204,8 +198,7 @@ DOT_SIZE = 2\n\
 # Radius of exclusion between other dots (in pixels)\n\
 \n\
 DOT_COLOR = "lime"\n\
-# The color used for dot markers in output plots. \n\
-# Only use default Python colors (https://matplotlib.org/3.5.0/gallery/color/named_colors.html)\n\
+# The color used for dot markers in output plots. Only use default Python colors (https://matplotlib.org/3.5.0/gallery/color/named_colors.html)\n\
 \n\
 DOT_THICKNESS = 0.5\n\
 # The line thickness used for dots in output plots. Default is 0.5.\n\
@@ -221,8 +214,7 @@ PLOT_BLOBS = False\n\
 # Whether to plot markers on the blobs in outputted figures. Default is False.\n\
 \n\
 BLOB_COLOR = "red"\n\
-# The color used for blob markers in output plots. \n\
-# Only use default Python colors (https://matplotlib.org/3.5.0/gallery/color/named_colors.html)\n\
+# The color used for blob markers in output plots. Only use default Python colors (https://matplotlib.org/3.5.0/gallery/color/named_colors.html)\n\
 \n\
 BLOB_THICKNESS = 0.5\n\
 # The line thickness used for blobs in output plots. Default is 0.5.\n\
@@ -235,8 +227,7 @@ PLOT_POLYGON = True\n\
 # Whether to plot the polygon in outputted figures. Default is True.\n\
 \n\
 POLYGON_COLOR = "darkorange"\n\
-# The color used for the polygon in output plots. \n\
-# Only use default Python colors (https://matplotlib.org/3.5.0/gallery/color/named_colors.html)\n\
+# The color used for the polygon in output plots. Only use default Python colors (https://matplotlib.org/3.5.0/gallery/color/named_colors.html)\n\
 \n\
 POLYGON_THICKNESS = 0.5\n\
 # The line thickness used for the polygon in output plots. Default is 0.5.\n\
@@ -250,8 +241,7 @@ DYNAMIC_WINDOW = True\n\
 \n\
 WINDOW_HEIGHT = 550\n\
 WINDOW_WIDTH = 650\n\
-# Dimensions of “threshold adjustment” and “region selection” windows in pixels.\n\
-# DYNAMIC_WINDOW must be set to False to set these values manually.\n\
+# Dimensions of “threshold adjustment” and “region selection” windows in pixels. DYNAMIC_WINDOW must be set to False to set these values manually.\n\
 \n\
 WINDOW_X = 10\n\
 WINDOW_Y = 30\n\
@@ -265,16 +255,13 @@ SAVE_FIGURES = False\n\
 # Whether the displayed figures should be saved in a "figures" directory. Default is False.\n\
 \n\
 DENSITY_OUTPUT_FILENAME = "densities.txt"\n\
-# The filename to be saved in the directory containing the images used for density measurement.\n\
-# This file will contain the measurements for each of those image files.\n\
+# The filename to be saved in the directory containing the images used for density measurement. This file will contain the measurements for each of those image files.\n\
 \n\
 LIFETIME_OUTPUT_FILENAME = "lifetimes.txt"\n\
 # The filename to be saved in the directory containing the images used for lifetime measurement.\n\
 \n\
 FIGURE_DIRECTORY_NAME = "figures/"\n\
-# The directory name where figures are to be saved (only if SAVE_FIGURES = True).\n\
-# The default is "figures/", but this can be changed if the user typically keeps a similarly\n\
-# named folder in their file structure for something else.\
+# The directory name where figures are to be saved (only if SAVE_FIGURES = True). The default is "figures/", but this can be changed if the user typically keeps a similarly named folder in their file structure for something else.\
 ')
 	
 	quit()
